You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ambari.apache.org by yu...@apache.org on 2013/08/21 08:56:23 UTC

git commit: AMBARI-2971. MapReduce2 HistoryServer failed to start with Class Not Found exception. (yusaku)

Updated Branches:
  refs/heads/trunk 649e16639 -> cbad978db


AMBARI-2971. MapReduce2 HistoryServer failed to start with Class Not Found exception. (yusaku)


Project: http://git-wip-us.apache.org/repos/asf/incubator-ambari/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ambari/commit/cbad978d
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ambari/tree/cbad978d
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ambari/diff/cbad978d

Branch: refs/heads/trunk
Commit: cbad978dbf38135f2159facd8c04bec1580f6a17
Parents: 649e166
Author: Yusaku Sako <yu...@hortonworks.com>
Authored: Tue Aug 20 23:49:23 2013 -0700
Committer: Yusaku Sako <yu...@hortonworks.com>
Committed: Tue Aug 20 23:49:23 2013 -0700

----------------------------------------------------------------------
 ambari-web/app/controllers/wizard/step8_controller.js | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ambari/blob/cbad978d/ambari-web/app/controllers/wizard/step8_controller.js
----------------------------------------------------------------------
diff --git a/ambari-web/app/controllers/wizard/step8_controller.js b/ambari-web/app/controllers/wizard/step8_controller.js
index 141b1d7..5d49005 100644
--- a/ambari-web/app/controllers/wizard/step8_controller.js
+++ b/ambari-web/app/controllers/wizard/step8_controller.js
@@ -1147,7 +1147,7 @@ App.WizardStep8Controller = Em.Controller.extend({
           var hostNames = _slave.hosts.mapProperty('hostName');
           switch (_client.component_name) {
             case 'HDFS_CLIENT':
               // install HDFS_CLIENT on HBASE_MASTER, HBASE_REGIONSERVER, and WEBHCAT_SERVER hosts
               masterHosts.filterProperty('component', 'HBASE_MASTER').filterProperty('isInstalled', false).forEach(function (_masterHost) {
                 hostNames.pushObject(_masterHost.hostName);
               }, this);
@@ -1157,6 +1157,9 @@ App.WizardStep8Controller = Em.Controller.extend({
               masterHosts.filterProperty('component', 'WEBHCAT_SERVER').filterProperty('isInstalled', false).forEach(function (_masterHost) {
                 hostNames.pushObject(_masterHost.hostName);
               }, this);
+              masterHosts.filterProperty('component', 'HISTORYSERVER').filterProperty('isInstalled', false).forEach(function (_masterHost) {
+                hostNames.pushObject(_masterHost.hostName);
+              }, this);
               break;
             case 'MAPREDUCE_CLIENT':
               // install MAPREDUCE_CLIENT on HIVE_SERVER, OOZIE_SERVER, NAGIOS_SERVER, and WEBHCAT_SERVER hosts
@@ -1147,7 +1147,7 @@ App.WizardStep8Controller = Em.Controller.extend({
           switch (_client.component_name) {
             case 'HDFS_CLIENT':
-              // install HDFS_CLIENT on HBASE_MASTER, HBASE_REGIONSERVER, and WEBHCAT_SERVER hosts
+              // install HDFS_CLIENT on HBASE_MASTER, HBASE_REGIONSERVER, WEBHCAT_SERVER, and HISTORYSERVER hosts
               masterHosts.filterProperty('component', 'HBASE_MASTER').filterProperty('isInstalled', false).forEach(function (_masterHost) {
                 hostNames.pushObject(_masterHost.hostName);